@@ -287,9 +287,9 @@ async function generateSiteJSON(options, requestHost, sub, pwd) {
                             };
                             // 添加isdr2参数到API URL
                             if (pwd) {
-                                t4site.api += `?pwd=${pwd}&adapt=dr`;
+                                t4site.api += `?pwd=${pwd}&do=dr`;
                             } else {
-                                t4site.api += `?adapt=dr`;
+                                t4site.api += `?do=dr`;
                             }
 
                             // 处理传参源的API参数
@@ -359,6 +359,7 @@ async function generateSiteJSON(options, requestHost, sub, pwd) {
                     ruleMeta.title = enableRuleName ? ruleMeta.title || baseName : baseName;
 
                     let fileSites = [];
+                    ext = ext || ruleMeta.ext || '';
                     if (baseName === 'push_agent') {
                         let key = 'push_agent';
                         let name = `${ruleMeta.title}(hipy)`;
@@ -396,23 +397,26 @@ async function generateSiteJSON(options, requestHost, sub, pwd) {
         await batchExecute(py_tasks, listener);
 
     }
-
+    const enable_cat = ENV.get('enable_cat', '1');
     // 根据用户是否启用cat源去生成对应配置
-    if (ENV.get('enable_cat', '1') === '1') {
+    if (enable_cat === '1' || enable_cat === '2') {
         const cat_files = readdirSync(catDir);
+        const api_type = enable_cat === '1' ? 3 : 4;
         let cat_valid_files = cat_files.filter((file) => file.endsWith('.js') && !file.startsWith('_')); // 筛选出不是 "_" 开头的 .py 文件
         // log(py_valid_files);
-        log(`开始生成catvod的t3配置，catDir:${catDir},源数量: ${cat_valid_files.length}`);
+        log(`开始生成catvod的T${api_type}配置，catDir:${catDir},源数量: ${cat_valid_files.length}`);
 
         const cat_tasks = cat_valid_files.map((file) => {
             return {
                 func: async ({file, catDir, requestHost, pwd, SitesMap}) => {
                     const baseName = path.basename(file, '.js'); // 去掉文件扩展名
                     const extJson = path.join(catDir, baseName + '.json');
-                    let api = `${requestHost}/cat/${file}`;
+                    let api = enable_cat === '1' ? `${requestHost}/cat/${file}` : `${requestHost}/api/${baseName}?do=cat`;  // 使用请求的 host 地址，避免硬编码端口
                     let ext = existsSync(extJson) ? `${requestHost}/cat/${file}` : '';
+
                     if (pwd) {
-                        api += `?pwd=${pwd}`;
+                        api += api_type === 3 ? '?' : '&';
+                        api += `pwd=${pwd}`;
                         if (ext) {
                             ext += `?pwd=${pwd}`;
                         }
@@ -445,6 +449,7 @@ async function generateSiteJSON(options, requestHost, sub, pwd) {
                     ruleMeta.title = enableRuleName ? ruleMeta.title || baseName : baseName;
 
                     let fileSites = [];
+                    ext = ext || ruleMeta.ext || '';
                     if (baseName === 'push_agent') {
                         let key = 'push_agent';
                         let name = `${ruleMeta.title}(cat)`;
@@ -466,7 +471,7 @@ async function generateSiteJSON(options, requestHost, sub, pwd) {
                         const site = {
                             key: fileSite.key,
                             name: fileSite.name,
-                            type: 3, // 固定值
+                            type: api_type, // 固定值
                             api,
                             ...ruleMeta,
                             ext: fileSite.ext || "", // 固定为空字符串
